clear all
close all

RTime=38; %Time of recontruction
res=0.1; %Resolution in degrees
SLchange=100; %Applied sea level change
sfac=5; %Smoothing radius in grid cells
cres=0.5; %Resolution of netcdf output
shiftp=20; %Shift for plotting figures in pixels
ShelfDepth=-100; %Depth of continental shelves without sea level change
ShallowDepth=-100; %Depth of shallow inland seas after sea level change
topomap=[0.85 0.85 0.85; jet(60); summer(15); flipud(copper(15)); gray(10); flipud(hot(20))]; %Colormap for topography plots

%Reconstructed Boundaries Mask
disp('Reading Boundaries Mask')

%Cut off empty edges of png image
R=imread(['Boundaries_' num2str(RTime) '.00Ma.png']);
N=find(sum(sum(R,3),2)~=0,1,'first');
S=find(sum(sum(R,3),2)~=0,1,'last');
nlat=S-N+1;
W=find(sum(sum(R,3),1)~=0,1,'first');
E=find(sum(sum(R,3),1)~=0,1,'last');
nlon=E-W+1;
Rc=R(N:S,W:E,:); clear R

%Global grid to plot the mask image
lonc=linspace(-180,180,nlon);
latc=linspace(-90,90,nlat);

%Plot the mask image
    scrsz = get(0,'ScreenSize'); figshift=0;
    h=figure('Position',[scrsz(3)/6 scrsz(4)/4 2*scrsz(3)/3 2*scrsz(4)/3]); figshift=figshift+shiftp;
    imagesc(lonc,latc,Rc)
    set(gca,'Xlim',[-180 180])
    set(gca,'Ylim',[-90 90])
    set(gca,'XTick',-180:30:180)
    set(gca,'YTick',-80:20:80)
    lonlab={'180W','150W','120W','90W','60W','30W','0','30E','60E','90E','120E','150E','180E'};
    latlab={'80S','60S','40S','20S','0','20N','40N','60N','80N'};
    set(gca,'XTickLabel',lonlab)
    set(gca,'YTickLabel',latlab)
    grid
    set(gca,'fontsize',12)
    set(gcf,'paperposition',[0 0 10 6])
    print(h,'-dpng','-r500','Boundaries_gridded') %Save image as png

%Extract land (LB), shelf (SB) and shallow regions (SS) from boundaries mask
LB=sum(Rc,3)==(3*255);
SB=(squeeze(Rc(:,:,3))==(255)).*(squeeze(Rc(:,:,2))==0).*(squeeze(Rc(:,:,1))==0);
SS=sum(Rc,3)==0;

%New grid that will be used for the reconstruction
[Lonc,Latc]=meshgrid(lonc,latc);
lon=-(180-res/2):res:(180-res/2);
lat=-(90-res/2):res:(90-res/2);
[Lon,Lat]=meshgrid(lon,lat);

%Interpolate masks onto the new grid
LB=flipud(round(interp2(Lonc,Latc,double(LB),Lon,Lat)));
SB=flipud(round(interp2(Lonc,Latc,SB,Lon,Lat)));
SS=flipud(round(interp2(Lonc,Latc,double(SS),Lon,Lat)));

%Additional Land Ocean Mask
disp('Reading Land Ocean Mask')

%Cut off empty edges of png
LO=imread(['LOMask_' num2str(RTime) '.00Ma.png']);
N=find(sum(sum(LO,3),2)~=0,1,'first');
S=find(sum(sum(LO,3),2)~=0,1,'last');
nlat=S-N+1;
W=find(sum(sum(LO,3),1)~=0,1,'first');
E=find(sum(sum(LO,3),1)~=0,1,'last');
nlon=E-W+1;
LOc=LO(N:S,W:E,:); clear LO
lonc=linspace(-180,180,nlon);
latc=linspace(-90,90,nlat);

%Plot the land ocean mask image
    h=figure('Position',[scrsz(3)/6+figshift scrsz(4)/4-figshift 2*scrsz(3)/3 2*scrsz(4)/3]); figshift=figshift+shiftp;
    imagesc(lonc,latc,LOc)
    axis equal
    set(gca,'Xlim',[-180 180])
    set(gca,'Ylim',[-90 90])
    set(gca,'XTick',-180:30:180)
    set(gca,'YTick',-80:20:80)
    set(gca,'XTickLabel',lonlab)
    set(gca,'YTickLabel',latlab)
    grid
    set(gca,'fontsize',12)
    set(gcf,'paperposition',[0 0 10 6])
    print(h,'-dpng','-r500','LOMask_gridded')

%Extract additional masks; land (LM), sea (SM), ocean (OM) and shallow sea
LM=(sum(LOc,3)==(3*255))+...
    (squeeze(LOc(:,:,3))==(51)).*(squeeze(LOc(:,:,2))==255).*(squeeze(LOc(:,:,1))==255);
SM=(squeeze(LOc(:,:,3))==(255)).*(squeeze(LOc(:,:,2))==0).*(squeeze(LOc(:,:,1))==0);
OM=sum(LOc,3)==0;
Shallow=(squeeze(LOc(:,:,3))==(255)).*(squeeze(LOc(:,:,2))==255).*(squeeze(LOc(:,:,1))==0);
%Masks for manipulating Asian topography
TibetM=(squeeze(LOc(:,:,3))==(0)).*(squeeze(LOc(:,:,2))==165).*(squeeze(LOc(:,:,1))==255);
LowTibetM=(squeeze(LOc(:,:,3))==(0)).*(squeeze(LOc(:,:,2))==128).*(squeeze(LOc(:,:,1))==0);
HimalayaM=(squeeze(LOc(:,:,3))==(0)).*(squeeze(LOc(:,:,2))==0).*(squeeze(LOc(:,:,1))==255);
EAsiaM=(squeeze(LOc(:,:,3))==(51)).*(squeeze(LOc(:,:,2))==255).*(squeeze(LOc(:,:,1))==255)+...
    (squeeze(LOc(:,:,3))==(18)).*(squeeze(LOc(:,:,2))==222).*(squeeze(LOc(:,:,1))==222);

%Extrapolate masks onto reconstruction grid
[Lonc,Latc]=meshgrid(lonc,latc);
LM=flipud(round(interp2(Lonc,Latc,double(LM),Lon,Lat)));
SM=flipud(round(interp2(Lonc,Latc,SM,Lon,Lat)));
OM=flipud(round(interp2(Lonc,Latc,double(OM),Lon,Lat)));
Shallow=flipud(round(interp2(Lonc,Latc,double(Shallow),Lon,Lat)));
TibetM=flipud(round(interp2(Lonc,Latc,double(TibetM),Lon,Lat)));
LowTibetM=flipud(round(interp2(Lonc,Latc,double(LowTibetM),Lon,Lat)));
HimalayaM=flipud(round(interp2(Lonc,Latc,double(HimalayaM),Lon,Lat)));
EAsiaM=flipud(round(interp2(Lonc,Latc,double(EAsiaM),Lon,Lat)));

%Mueller Reconstructed Bathymetry
disp('Building Topobathymetry')

%Load transformed mueller bathymetry file
MuellerBathy=ncread(['Mueller' num2str(RTime) 'Ma_cor.nc'],'Band1');
MuellerBathy=MuellerBathy';
MuellerBathy(isnan(MuellerBathy))=1;

%Remove Mediterranean Reconstruction
MuellerBathy(1000:1277,1733:2445)=nan;

%Initialise topobathymetry file and apply Mueller bathymetry
topobathy=nan(size(LB));
topobathy(MuellerBathy<0)=MuellerBathy(MuellerBathy<0); %Exclude regions above sea level

%Ocean Floor Age Reconstruction

age=ncread(['Age_' num2str(RTime) '.00Ma.nc'],'Band1'); age=(age-RTime)';
%Read and apply age grid
OceanFloor=nan(size(age));
%Determine depth using age-depth relationship
OceanFloor(age>0)=-2620-330*sqrt(age(age>0));
OceanFloor(age>90)=-5750;

%Plot ocean bathymetry and shelf boundary contours
    h=figure('Position',[scrsz(3)/6+figshift scrsz(4)/4-figshift 2*scrsz(3)/3 2*scrsz(4)/3]); figshift=figshift+shiftp;
    imagesc(lon,lat,OceanFloor,[-6100 6000])
    hold on
    contour(lon,lat,LB+SB,[1 1],'Color','k')
    colormap(topomap)
    hc=colorbar;
    elevlab={'-6000m','-4000m','-2000m','0m','2000m','4000m','6000m'};
    set(hc,'yticklabel',elevlab)
    hold on
    set(gca,'Ydir','normal')
    set(gca,'Xlim',[-180 180])
    set(gca,'Ylim',[-90 90])
    set(gca,'XTick',-180:30:180)
    set(gca,'YTick',-80:20:80)
    set(gca,'XTickLabel',lonlab)
    set(gca,'YTickLabel',latlab)
    grid
    set(gca,'Fontsize',12)
    title(['Reconstructed Ocean Floor ' num2str(RTime) 'Ma'],'Fontsize',14)
    set(gcf,'paperposition',[0 0 10 6])
    print(h,'-dpng','-r300',['Step1_' num2str(RTime)])

%Update the bathymetry, keeping mueller only where agegrid is undefined
topobathy(~isnan(OceanFloor))=OceanFloor(~isnan(OceanFloor));

%Plot new bathymetry with missing regions filled by muller reconstruction
    h=figure('Position',[scrsz(3)/6+figshift scrsz(4)/4-figshift 2*scrsz(3)/3 2*scrsz(4)/3]); figshift=figshift+shiftp;
    imagesc(lon,lat,topobathy,[-6100 6000])
    hold on
    contour(lon,lat,LB+SB,[1 1],'Color','k')
    colormap(topomap)
    hc=colorbar;
    set(hc,'yticklabel',elevlab)
    hold on
    set(gca,'Ydir','normal')
    set(gca,'Xlim',[-180 180])
    set(gca,'Ylim',[-90 90])
    set(gca,'XTick',-180:30:180)
    set(gca,'YTick',-80:20:80)
    set(gca,'XTickLabel',lonlab)
    set(gca,'YTickLabel',latlab)
    grid
    set(gca,'Fontsize',12)
    title(['Reconstructed Ocean Floor using Mueller Data ' num2str(RTime) 'Ma'],'Fontsize',14)
    set(gcf,'paperposition',[0 0 10 6])
    print(h,'-dpng','-r300',['Step2_' num2str(RTime)])

%Continental Shelves and Shallow Regions

sbathy=ncread(['SS_' num2str(RTime) '.00Ma.nc'],'Band1'); sbathy=sbathy';
sbathy(sbathy<topobathy)=topobathy(sbathy<topobathy); %Remove parts that are deeper than current bathymetry
topobathy(SS==1)=sbathy(SS==1);
topobathy(SB==1)=ShelfDepth;
%Replace continental shelf by shallow region depth where the latter is deeper and less than 2000m
topobathy(((SB==1).*(sbathy>-2000).*(sbathy<ShelfDepth))==1)=sbathy(((SB==1).*(sbathy>-2000).*(sbathy<ShelfDepth))==1);

%Plot current ocean and sea bathymetry
    h=figure('Position',[scrsz(3)/6+figshift scrsz(4)/4-figshift 2*scrsz(3)/3 2*scrsz(4)/3]); figshift=figshift+shiftp;
    imagesc(lon,lat,topobathy,[-6100 6000])
    colormap(topomap)
    hc=colorbar;
    set(hc,'yticklabel',elevlab)
    hold on
    set(gca,'Ydir','normal')
    set(gca,'Xlim',[-180 180])
    set(gca,'Ylim',[-90 90])
    set(gca,'XTick',-180:30:180)
    set(gca,'YTick',-80:20:80)
    set(gca,'XTickLabel',lonlab)
    set(gca,'YTickLabel',latlab)
    grid
    set(gca,'Fontsize',12)
    title(['Reconstructed Ocean Floor with Continental Shelves and Plateaus ' num2str(RTime) 'Ma'],'Fontsize',14)
    set(gcf,'paperposition',[0 0 10 6])
    print(h,'-dpng','-r300',['Step3_' num2str(RTime)])

%Reconstructed Topography

topo=ncread(['TopoBR_' num2str(RTime) '.00Ma.nc'],'Band1'); topo=topo';
%Implement adjusted present day topography
topobathy(LB==1)=topo(LB==1);
topobathy((LB.*isnan(topo))==1)=0; %Put elevation to 0 where land mask is defined but not the topography

%Plot the combined topography and shifted present day bathymetry
    h=figure('Position',[scrsz(3)/6+figshift scrsz(4)/4-figshift 2*scrsz(3)/3 2*scrsz(4)/3]); figshift=figshift+shiftp;
    imagesc(lon,lat,topobathy,[-6100 6000])
    colormap(topomap)
    hc=colorbar;
    set(hc,'yticklabel',elevlab)
    hold on
    set(gca,'Ydir','normal')
    set(gca,'Xlim',[-180 180])
    set(gca,'Ylim',[-90 90])
    set(gca,'XTick',-180:30:180)
    set(gca,'YTick',-80:20:80)
    set(gca,'XTickLabel',lonlab)
    set(gca,'YTickLabel',latlab)
    grid
    set(gca,'Fontsize',12)
    title(['Reconstructed Topobathymetry using Present Day Topography ' num2str(RTime) 'Ma'],'Fontsize',14)
    set(gcf,'paperposition',[0 0 10 6])
    print(h,'-dpng','-r300',['Step4_' num2str(RTime)])

%Greenland and Antarctica Isostatic Adjustment

topoI=ncread(['Topo_' num2str(RTime) '.00Ma.nc'],'Band1'); topoI=topoI';
%Correct topography by 30% of difference between current actual and bedrock elevation
Greenland=0.3*(topoI(1400:1700,1300:1750)-topo(1400:1700,1300:1750));
Greenland(isnan(Greenland))=0; Greenland(Greenland<0)=0;
topobathy(1400:1700,1300:1750)=topobathy(1400:1700,1300:1750)+Greenland;

Antarctica=0.3*(topoI(1:300,:)-topo(1:300,:)); %Consider everything south of 70deg
Antarctica(isnan(Antarctica))=0; Antarctica(Antarctica<0)=0;
topobathy(1:300,:)=topobathy(1:300,:)+Antarctica;

%Tethys ocean
topobathy(OM==1)=-4500+SLchange;

%Lower Mountain Ranges
Andes=topobathy(300:900,1050:1300);
%Divide elevation above 1000m by 4
Andes(Andes>1000)=1000+((Andes(Andes>1000))-1000)/4;
topobathy(300:900,1050:1300)=Andes;

Himalaya=topobathy(HimalayaM==1); %Use Himalaya mask
Himalaya(Himalaya>2000)=2000+((Himalaya(Himalaya>2000))-2000)/2;
topobathy(HimalayaM==1)=Himalaya;

Tibet=topobathy(TibetM==1); %Use Tibet mask
Tibet(Tibet>1500)=1500+((Tibet(Tibet>1500))-1500)/3;
topobathy(TibetM==1)=Tibet;

LowTibet=topobathy(LowTibetM==1); %Lowland north of Himalaya
LowTibet=LowTibet/5;
topobathy(LowTibetM==1)=LowTibet;

EAsia=topobathy(EAsiaM==1); %Mask surrounding Himalaya and Tibet
EAsia(EAsia>1000)=1000+((EAsia(EAsia>1000))-1000)/4;
topobathy(EAsiaM==1)=EAsia;

ME=topobathy(1050:1350,2050:2400); %Middle East topography caused by Africa-Eurasia collision
ME(ME>1000)=1000+((ME(ME>1000))-1000)/2;
topobathy(1050:1350,2050:2400)=ME;

Rift=topobathy(750:1000,2100:2250); %West African Rift was not yet formed
Rift(Rift>1000)=1000+((Rift(Rift>1000))-1000)/2;
topobathy(750:1000,2100:2250)=Rift;

WSierra=topobathy(1250:1350,750:825); %Western Sierras in Northern America were lower
WSierra(WSierra>1000)=1000+((WSierra(WSierra>1000))-1000)/2;
topobathy(1250:1350,750:825)=WSierra;

%Plot adjusted topobathymetry
    h=figure('Position',[scrsz(3)/6+figshift scrsz(4)/4-figshift 2*scrsz(3)/3 2*scrsz(4)/3]); figshift=figshift+shiftp;
    imagesc(lon,lat,topobathy,[-6100 6000])
    colormap(topomap)
    hc=colorbar;
    set(hc,'yticklabel',elevlab)
    hold on
    set(gca,'Ydir','normal')
    set(gca,'Xlim',[-180 180])
    set(gca,'Ylim',[-90 90])
    set(gca,'XTick',-180:30:180)
    set(gca,'YTick',-80:20:80)
    set(gca,'XTickLabel',lonlab)
    set(gca,'YTickLabel',latlab)
    grid
    set(gca,'Fontsize',12)
    title(['Reconstructed Topobathymetry with Custom Adjustments ' num2str(RTime) 'Ma'],'Fontsize',14)
    set(gcf,'paperposition',[0 0 10 6])
    print(h,'-dpng','-r300',['Step5_' num2str(RTime)])

%Save backup of topobathymetry
topobathybu=topobathy;
    
%Correct Shallow Regions

NER=topobathy(500:850,2570:2670); %Ninety-East ridge is accentuated
NER(NER>-3000)=-3000+55*sqrt(3000+NER(NER>-3000));
topobathy(500:850,2570:2670)=NER;

TR=topobathy(260:315,3300:3450); %Tasman Rise is made higher
TR(TR>-3000)=-3000+55*sqrt(3000+TR(TR>-3000));
topobathy(260:315,3300:3450)=TR;

%Wilson Antarctic Reconstruction
WAT=nan(size(topobathy));
topo=ncread(['WilsonAR_' num2str(RTime) '.00Ma.nc'],'Band1');
WAT(1:300,:)=topo';
%Apply (adjusted) Wilson reconstruction but only topography and coasts
topobathy(WAT>ShelfDepth)=WAT(WAT>ShelfDepth);

%Plot topobathymetry including Antarctic reconstruction
    h=figure('Position',[scrsz(3)/6+figshift scrsz(4)/4-figshift 2*scrsz(3)/3 2*scrsz(4)/3]); figshift=figshift+shiftp;
    imagesc(lon,lat,topobathy,[-6100 6000])
    colormap(topomap)
    hc=colorbar;
    set(hc,'yticklabel',elevlab)
    hold on
    set(gca,'Ydir','normal')
    set(gca,'Xlim',[-180 180])
    set(gca,'Ylim',[-90 90])
    set(gca,'XTick',-180:30:180)
    set(gca,'YTick',-80:20:80)
    set(gca,'XTickLabel',lonlab)
    set(gca,'YTickLabel',latlab)
    grid
    set(gca,'Fontsize',12)
    title(['Reconstructed Topobathymetry using Wilson (2012) Antarctic Topography ' num2str(RTime) 'Ma'],'Fontsize',14)
    set(gcf,'paperposition',[0 0 10 6])
    print(h,'-dpng','-r300',['Step6_' num2str(RTime)])

%Additional Sea Ocean Mask

%Correct to (final) specified depth regardless of current value, correct for sea level rise
topobathy(((Shallow==1).*(topobathy>ShallowDepth))==1)=ShallowDepth+SLchange;
topobathy(((Shallow==1).*isnan(topobathy))==1)=ShallowDepth+SLchange;
topobathy(SM==1)=-1000+SLchange;
topobathy(OM==1)=-4500+SLchange;

%Plot topobathymetry with mask corrections
    h=figure('Position',[scrsz(3)/6+figshift scrsz(4)/4-figshift 2*scrsz(3)/3 2*scrsz(4)/3]); figshift=figshift+shiftp;
    imagesc(lon,lat,topobathy,[-6100 6000])
    colormap(topomap)
    hc=colorbar;
    set(hc,'yticklabel',elevlab)
    hold on
    set(gca,'Ydir','normal')
    set(gca,'Xlim',[-180 180])
    set(gca,'Ylim',[-90 90])
    set(gca,'XTick',-180:30:180)
    set(gca,'YTick',-80:20:80)
    set(gca,'XTickLabel',lonlab)
    set(gca,'YTickLabel',latlab)
    grid
    set(gca,'Fontsize',12)
    title(['Reconstructed Topobathymetry ' num2str(RTime) 'Ma'],'Fontsize',14)
    set(gcf,'paperposition',[0 0 10 6])
    print(h,'-dpng','-r300',['Step7_' num2str(RTime)])

%Detect custom changes made
TBadj=(topobathy-topobathybu)~=0;
TBadj(isnan(topobathybu))=1;
TBadj(isnan(topobathy))=0;
TBadj(((LM==1).*((topobathy-SLchange)<0))==1)=1;

    h=figure('Position',[scrsz(3)/6+figshift scrsz(4)/4-figshift 2*scrsz(3)/3 2*scrsz(4)/3]); figshift=figshift+shiftp;
    imagesc(lon,lat,topobathy,[-6100 6000])
    colormap(topomap)
    hc=colorbar;
    set(hc,'yticklabel',elevlab)
    hold on
    [clines,hval]=contourf(lon,lat,double(TBadj),[0.5 0.5]);
    hold off
    hpatch=findobj(hval,'Type','patch');
    hf=hatchfill(hpatch,'speckle',100,1/4);
    set(gca,'Ydir','normal')
    set(gca,'Xlim',[-180 180])
    set(gca,'Ylim',[-90 90])
    set(gca,'XTick',-180:30:180)
    set(gca,'YTick',-80:20:80)
    set(gca,'XTickLabel',lonlab)
    set(gca,'YTickLabel',latlab)
    grid
    set(gca,'Fontsize',12)
    title(['Specific Changes ' num2str(RTime) 'Ma'],'Fontsize',14)
    set(gcf,'paperposition',[0 0 10 6])
    print(h,'-dpng','-r300',['Step7adj_' num2str(RTime)])

%Interpolate Missing Values
disp('Interpolating Missing Values')

edge=10; %Extra edge for interpolation along date line separation
nlon=length(lon); nlat=length(lat); %Redifine nlon and nlat for reconstruction grid
topobathy=[topobathy(:,(nlon-edge+1):nlon) topobathy topobathy(:,1:edge)];
topobathy=inpaintn(topobathy); %Inpaintn algorithm developed by Damien Garcia (Garcia, 2010, Wang et al., 2012)
topobathy=topobathy(:,(edge+1):(edge+nlon)); %Cut off extra edges

%Adjust Global Sea Level
topobathy=topobathy-SLchange;

%Correct Land Mask and fill in Last Gaps

topobathy((LM.*(topobathy<0))==1)=0; %Similar to sea/ocean mask, submerged land put back to 0
topobathy((LM.*isnan(topobathy))==1)=0; %Possible undefined points are put to 0
topobathy(isnan(topobathy))=-4000; %Undifined points in the ocean put to -4000m
topobathy(topobathy<-6000)=-6000; %Points below 6000m depth are corrected

%Plot complete topobathymetry after interpolation and corrections
    h=figure('Position',[scrsz(3)/6+figshift scrsz(4)/4-figshift 2*scrsz(3)/3 2*scrsz(4)/3]); figshift=figshift+shiftp;
    imagesc(lon,lat,topobathy,[-6100 6000])
    colormap(topomap)
    hc=colorbar;
    set(hc,'yticklabel',elevlab)
    set(gca,'Ydir','normal')
    set(gca,'Xlim',[-180 180])
    set(gca,'Ylim',[-90 90])
    set(gca,'XTick',-180:30:180)
    set(gca,'YTick',-80:20:80)
    set(gca,'XTickLabel',lonlab)
    set(gca,'YTickLabel',latlab)
    grid
    set(gca,'Fontsize',12)
    title(['Reconstructed Topobathymetry, Interpolating Missing Values ' num2str(RTime) 'Ma'],'Fontsize',14)
    set(gcf,'paperposition',[0 0 10 6])
    print(h,'-dpng','-r300',['Step8_' num2str(RTime)])

%Smoothing
disp('Smoothing')
topobathys=zeros(size(topobathy)); %Initialise smoothed topobathymetry

for iz=1:nlon
    for im=1:nlat
        %Define smoothing mask; periodic boundary along date line
        lonvec=mod((iz-sfac):(iz+sfac),nlon); lonvec(lonvec==0)=nlon;
        latvec=max(1,im-sfac):min(nlat,im+sfac);
        topobathys(im,iz)=mean(mean(topobathy(latvec,lonvec)));
    end
end

%Plot smooth topobathymetry
    h=figure('Position',[scrsz(3)/6+figshift scrsz(4)/4-figshift 2*scrsz(3)/3 2*scrsz(4)/3]); figshift=figshift+shiftp;
    imagesc(lon,lat,topobathys,[-6100 6000])
    colormap(topomap)
    hc=colorbar;
    set(hc,'yticklabel',elevlab)
    set(gca,'Ydir','normal')
    set(gca,'Xlim',[-180 180])
    set(gca,'Ylim',[-90 90])
    set(gca,'XTick',-180:30:180)
    set(gca,'YTick',-80:20:80)
    set(gca,'XTickLabel',lonlab)
    set(gca,'YTickLabel',latlab)
    grid
    set(gca,'Fontsize',12)
    title(['Smoothed Topobathymetry ' num2str(RTime) 'Ma'],'Fontsize',14)
    set(gcf,'paperposition',[0 0 10 6])
    print(h,'-dpng','-r300',['Step9_' num2str(RTime)])

%Saving
disp('Saving Result')
save(['TopoBathy' num2str(RTime) '.mat'],'topobathys'); %Save as MATLAB binary

%Create Netcdf File to store result at full resolution
ncid = netcdf.create(['TopoBathy' num2str(RTime) '.nc'],'NC_WRITE');
dimidlat = netcdf.defDim(ncid,'latitude',nlat);
dimidlon = netcdf.defDim(ncid,'longitude',nlon);
latitude_ID=netcdf.defVar(ncid,'latitude','double',dimidlat);
longitude_ID=netcdf.defVar(ncid,'longitude','double',dimidlon);
Z_ID = netcdf.defVar(ncid,'Z','double',[dimidlon dimidlat]);
netcdf.endDef(ncid);
netcdf.putVar(ncid,latitude_ID,lat);
netcdf.putVar(ncid,longitude_ID,lon);
netcdf.putVar(ncid,Z_ID,topobathys'); %Store smoothed topobathymetry
netcdf.close(ncid)

%Interpolating to output grid with specified resolution
disp('Interpolating to Desired Grid')
lonc=-(180-cres/2):cres:(180-cres/2); %Defining reduced grid
latc=-(90-cres/2):cres:(90-cres/2);
[Lonc,Latc]=meshgrid(lonc,latc);
topobathyc=interp2(Lon,Lat,topobathys,Lonc,Latc);

%Plot reduced resolution topobathymetry
    h=figure('Position',[scrsz(3)/6+figshift scrsz(4)/4-figshift 2*scrsz(3)/3 2*scrsz(4)/3]); figshift=figshift+shiftp;
    imagesc(lon,lat,topobathyc,[-6100 6000])
    colormap(topomap)
    hc=colorbar;
    set(hc,'yticklabel',elevlab)
    set(gca,'Ydir','normal')
    set(gca,'Xlim',[-180 180])
    set(gca,'Ylim',[-90 90])
    set(gca,'XTick',-180:30:180)
    set(gca,'YTick',-80:20:80)
    set(gca,'XTickLabel',lonlab)
    set(gca,'YTickLabel',latlab)
    grid
    set(gca,'Fontsize',12)
    title(['Smoothed Topobathymetry ' num2str(RTime) 'Ma at ' num2str(cres) 'deg'],'Fontsize',14)
    set(gcf,'paperposition',[0 0 10 6])
    print(h,'-dpng','-r300',['Step10_' num2str(RTime)])


%Create netcdf file at reduced resolution
ncid = netcdf.create(['TopoBathyc' num2str(RTime) '.nc'],'NC_WRITE');
dimidlat = netcdf.defDim(ncid,'latitude',length(latc));
dimidlon = netcdf.defDim(ncid,'longitude',length(lonc));
latitude_ID=netcdf.defVar(ncid,'latitude','double',dimidlat);
longitude_ID=netcdf.defVar(ncid,'longitude','double',dimidlon);
Z_ID = netcdf.defVar(ncid,'Z','double',[dimidlon dimidlat]);
netcdf.endDef(ncid);
netcdf.putVar(ncid,latitude_ID,latc);
netcdf.putVar(ncid,longitude_ID,lonc);
netcdf.putVar(ncid,Z_ID,topobathyc'); %Interpolated topobathymetry field
netcdf.close(ncid)

%End of script